@@ -137,11 +137,8 @@ class Service:
     def main(cls, self) -> NoReturn:
         """Program entry point"""
 
-        import argparse
         import qubesdb  # pylint: disable=import-error
 
-        argparse.ArgumentParser().parse_args()
-
         target_domain = qubesdb.QubesDB().read("/name")
         if target_domain is None:
             # dom0 doesn't have a /name value in its QubesDB
